==> haskell-hslua-module-doclayout-1.0.4-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-doclayout
version:              1.0.4
visibility:           public
id:                   hslua-module-doclayout-1.0.4-GJQbZF0VAosK3pemyhbvpS
key:                  hslua-module-doclayout-1.0.4-GJQbZF0VAosK3pemyhbvpS
license:              MIT
copyright:            © 2020-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  167b44ae334af1f4d4fc7c51b9ad8e93
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hslua-module-doclayout-1.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hslua-module-doclayout-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.0.4-GJQbZF0VAosK3pemyhbvpS
depends:
    base-4.15.1.0 doclayout-0.3.1.1-9iglzCAkJMzDGMqI5conPR
    hslua-2.1.0-LIvgjiVPeCmKZdYA7q4SOZ text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-doclayout-1.0.4-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-doclayout
version:              1.0.4
visibility:           public
id:                   hslua-module-doclayout-1.0.4-FZVf1ZvxgAGBnnvdpCyMcH
key:                  hslua-module-doclayout-1.0.4-FZVf1ZvxgAGBnnvdpCyMcH
license:              MIT
copyright:            © 2020-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  6373526f384c06026fdedbd7acf77f92
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hslua-module-doclayout-1.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hslua-module-doclayout-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.0.4-FZVf1ZvxgAGBnnvdpCyMcH
depends:
    base-4.15.1.0 doclayout-0.3.1.1-8hB7PqlGwX0I0IwvKFpaVK
    hslua-2.1.0-E1c8RbCtXaV15WJiX66igD text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
